@@ -64,6 +64,7 @@ mock_user(PyObject *self, PyObject *args, PyObject *kwds)
     static char *kwlist[] =
         { "canonical_name", "display_name", "is_loaded", NULL };
 
+    /* TODO: free canonical_name and display_name memory? */
     if (!PyArg_ParseTupleAndKeywords(args, kwds, "es|esb", kwlist,
                                      ENCODING, &canonical_name,
                                      ENCODING, &display_name,
@@ -73,7 +74,7 @@ mock_user(PyObject *self, PyObject *args, PyObject *kwds)
         display_name = canonical_name;
 
     user = mocksp_user_create(canonical_name, display_name, is_loaded);
-    return User_FromSpotify(user);
+    return User_FromSpotify(user, 0);
 }
 
 /// Generate a mock spotify.Albumbrowse object
@@ -94,6 +95,7 @@ mock_albumbrowse(PyObject *self, PyObject *args, PyObject *kwds)
         { "album", "tracks", "artist", "error", "request_duration",
           "copyrights", "review", NULL };
 
+    /* TODO: free review memory? */
     if (!PyArg_ParseTupleAndKeywords(args, kwds,
                 "O!O!|O!iiO!es", kwlist, &AlbumType, &album, &PyList_Type,
                 &py_tracks, &ArtistType, &artist, &error, &request_duration,
@@ -123,7 +125,7 @@ mock_albumbrowse(PyObject *self, PyObject *args, PyObject *kwds)
                                    artist, num_copyrights,
                                    (const char **)copyrights, num_tracks, tracks,
                                    (const char *)review, NULL, NULL);
-    return AlbumBrowser_FromSpotify(ab);
+    return AlbumBrowser_FromSpotify(ab, 0);
 }
 
 /// Generate a mock spotify.Artistbrowse object
@@ -146,6 +148,7 @@ mock_artistbrowse(PyObject *self, PyObject *args, PyObject *kwds)
         { "artist", "tracks", "albums", "similar_artists", "error",
           "request_duration", "portraits", "biography", "type", NULL };
 
+    /* TODO: free biography memory? */
     if (!PyArg_ParseTupleAndKeywords(args, kwds,
                 "O!O!O!O!|iiO!esiOO", kwlist, &ArtistType, &artist,
                 &PyList_Type, &py_tracks, &PyList_Type, &py_albums,
@@ -187,7 +190,7 @@ mock_artistbrowse(PyObject *self, PyObject *args, PyObject *kwds)
                                     num_similar_artists, similar_artists,
                                     0, NULL,
                                     (const char *)biography, type, NULL, NULL);
-    return ArtistBrowser_FromSpotify(ab);
+    return ArtistBrowser_FromSpotify(ab, 0);
 }
 
 /// Generate a mock spotify.Artist python object
@@ -202,12 +205,13 @@ mock_artist(PyObject *self, PyObject *args, PyObject *kwds)
     static char *kwlist[] =
         { "name", "portrait", "is_loaded", NULL };
 
+    /* TODO: free name memory? */
     if (!PyArg_ParseTupleAndKeywords(args, kwds, "es|sb", kwlist,
                                      ENCODING, &name, &portrait, &is_loaded))
         return NULL;
 
     artist = mocksp_artist_create(name, portrait, is_loaded);
-    return Artist_FromSpotify(artist);
+    return Artist_FromSpotify(artist, 0);
 }
 
 /// Generate a mock spotify.Track python object
@@ -233,6 +237,7 @@ mock_track(PyObject *self, PyObject *args, PyObject *kwds)
           "index", "error", "is_loaded", "availability", "status", "is_local",
           "is_autolinked", "is_starred", "is_placeholder", "playable", NULL };
 
+    /* TODO: free name memory? */
     if (!PyArg_ParseTupleAndKeywords(args, kwds, "esO!O!|iiiiibiibbbbO!",
             kwlist,
             ENCODING, &name, &PyList_Type, &py_artists, &AlbumType, &album,
@@ -254,7 +259,7 @@ mock_track(PyObject *self, PyObject *args, PyObject *kwds)
                                 is_loaded, availability, status, is_local,
                                 is_autolinked, sp_playable, is_starred,
                                 is_placeholder);
-    return Track_FromSpotify(track);
+    return Track_FromSpotify(track, 0);
 }
 
 /// Generate a mock spotify.Album python object
@@ -273,6 +278,7 @@ mock_album(PyObject *self, PyObject *args, PyObject *kwds)
         { "name", "artist", "year", "cover", "type", "is_loaded",
           "is_available", NULL };
 
+    /* TODO: free name memory? */
     if (!PyArg_ParseTupleAndKeywords(args, kwds, "esO!|isibb", kwlist,
                 ENCODING, &name, &ArtistType, &artist, &year, &cover, &type,
                 &is_loaded, &is_available))
@@ -281,7 +287,7 @@ mock_album(PyObject *self, PyObject *args, PyObject *kwds)
     album = mocksp_album_create(name, artist->_artist, year,
                                 (const byte *)cover, type, is_loaded,
                                 is_available);
-    return Album_FromSpotify(album);
+    return Album_FromSpotify(album, 0);
 }
 
 /// Generate a mock spotify.Playlist python object
@@ -313,6 +319,7 @@ mock_playlist(PyObject *self, PyObject *args, PyObject *kwds)
           "has_pending_changes", "is_in_ram", "offline_status",
           "offline_download_completed", NULL };
 
+    /* TODO: free name memory? */
     if (!PyArg_ParseTupleAndKeywords(args, kwds, "esO!O!|O!iessbbbbii", kwlist,
                 ENCODING, &name, &PyList_Type, &py_tracks, &UserType, &owner,
                 &PyList_Type, &py_subscribers, &num_subscribers, ENCODING,
@@ -327,6 +334,7 @@ mock_playlist(PyObject *self, PyObject *args, PyObject *kwds)
         create_time = 0;
         message = "";
         seen = 0;
+        /* TODO: free message memory? */
         if (!PyArg_ParseTuple(PyList_GET_ITEM(py_tracks, i), "O!O!|iesb",
                               &TrackType, &track, &UserType, &creator,
                               &create_time, ENCODING, &message, &seen))
@@ -358,7 +366,7 @@ mock_playlist(PyObject *self, PyObject *args, PyObject *kwds)
                     subscribers, is_in_ram, offline_status,
                     offline_download_completed, num_tracks, tracks);
     free(tracks);
-    return Playlist_FromSpotify(playlist);
+    return Playlist_FromSpotify(playlist, 0);
 }
 
 /// Generate a mock spotify.PlaylistContainer python object
@@ -413,7 +421,7 @@ mock_playlistcontainer(PyObject *self, PyObject *args, PyObject *kwds)
                                                 num_playlists, playlists,
                                                 NULL, NULL);
     free(playlists);
-    return PlaylistContainer_FromSpotify(container);
+    return PlaylistContainer_FromSpotify(container, 0);
 }
 
 /// Generate a mock spotify.PlaylistFolder python object
@@ -474,6 +482,7 @@ mock_search(PyObject *self, PyObject *args, PyObject *kwds)
           "total_tracks", "total_albums", "total_artists", "did_you_mean",
           "error", NULL };
 
+    /* TODO: free query and did_you_mean memory? */
     if (!PyArg_ParseTupleAndKeywords(args, kwds,
                 "esO!O!O!|iiiesi", kwlist, ENCODING, &query,
                 &PyList_Type, &py_tracks, &PyList_Type, &py_albums,
@@ -519,7 +528,7 @@ mock_search(PyObject *self, PyObject *args, PyObject *kwds)
     free(tracks);
     free(albums);
     free(artists);
-    return Results_FromSpotify(search);
+    return Results_FromSpotify(search, 0);
 }
 
 /// Generate a mock spotify.Session python object
@@ -537,6 +546,7 @@ mock_session(PyObject *self, PyObject *args, PyObject *kwds)
 
     static char *kwlist[] = { "username", "inbox", NULL};
 
+    /* TODO: free username memory? */
     if (!PyArg_ParseTupleAndKeywords(args, kwds, "|esO!", kwlist,
                                      ENCODING, &username,
                                      &PlaylistType, &inbox))
@@ -600,7 +610,7 @@ mock_toplistbrowse(PyObject *self, PyObject *args, PyObject *kwds)
     tb = mocksp_toplistbrowse_create(error, request_duration, num_artists,
                                     artists, num_albums, albums, num_tracks,
                                     tracks, NULL, NULL);
-    return ToplistBrowser_FromSpotify(tb);
+    return ToplistBrowser_FromSpotify(tb, 0);
 }
 
 /************************* REGISTRY MANIPULATION ****************************/
